# Using Tags and Custom Fields
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields#overview)
  * [When to Use Tags](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields#when-to-use-tags)
  * [When to Use Custom Attributes](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields#when-to-use-custom-attributes)
  * [Single- and Multiple-Select Fields and Tag Groups](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields#single--and-multiple-select-fields-and-tag-groups)


Learn how to effectively use tags and custom fields in SAP LeanIX.
